@@ -69,7 +69,8 @@ invite <- function(email, name = NULL, notify = TRUE, id_method = "pwhash",
 #' resetPassword("me@example.com")
 #' }
 resetPassword <- function(email) {
-    app <- getOption("crunch.api")
+    deprecate_password("resetPassword")
+    app <- envOrOption("crunch.api")
     invisible(crPOST(absoluteURL("public/password_reset/", app),
         body = toJSON(list(
             email = email,
