@@ -182,7 +182,7 @@ with_test_authentication({
     test_that("Can download a csv of a dataset", {
         skip_on_local_backend("Vagrant host doesn't serve files correctly")
         filename <- tempfile()
-        exportDataset(ds, file = filename)
+        exportDataset(ds, file = filename, format = "csv")
         df2 <- read.csv(filename)
         validExport(df2)
     })
